/*
TASK: cut
LANG: C++
*/
#include <iostream>
#include <vector>
#include <functional>
#include <algorithm>
#include <queue>

#include <assert.h>
#include <stdlib.h>

using namespace std;

struct Tree {
	vector<int> t;
	int mark;
	int b;

	Tree(int size) : mark(0xABCDEF00) {
		int p;

		for (p = 0; size > 0; ++p)
			size /= 2;
		++p;

		b = 1<<p;
		t.insert(t.begin(), (size_t) (2<<p), mark);
	};

	void add(int p, int x) {
		int c;

		assert(p >= 0 && p < b);

		c = b+p;
		t[c] = x;
		c /= 2;
		while (c >= 1) {
			if (t[c*2+1] != mark)
				t[c] = t[c*2+1];
			else
				t[c] = t[c*2];
			c /= 2;
		}
	};

	int query(int p) {
		int c;

		assert(p >= 0 && p < b);

		c = b+p;
		while (t[c] == mark && c > 1) {
			if (c%2 == 1)
				c /= 2;
			else {
				if (((c-1)^c) > c) break;
				c--;
			}
		}

		return t[c];
	};
};

struct Cross {
	int x, y;
	int ti, tp;

	Cross(int a, int b) : x(a), y(b) {};
	bool operator==(const Cross &a) {
		return (a.x == x) && (a.y == y);
	}
	void print() {
		cout << x << " " << y << "; tree " << ti << " " << tp << endl; //debug only
	}
};


struct Cut {
	int x1, y1;
	int x2, y2;
	bool u1, u2;
	bool placed;

	Cut() : x1(0), y1(0), x2(0), y2(0), u1(false), u2(false), placed(false) {};
	Cut(int a, int b, int c, int d) : x1(a), y1(b), x2(c), y2(d), u1(false), u2(false), placed(false)
		{assert(x1<=x2); assert(y1<=y2);};

	Cut(int a, int b, int c, int d, bool e, bool f) : x1(a), y1(b), x2(c), y2(d), u1(e), u2(f), placed(false)
		{assert(x1<=x2); assert(y1<=y2);};

	void print() {
		//cout << x1 << " " << y1 << " " << x2 << " " << y2 << endl;
		printf("%d %d %d %d\n", x1, y1, x2, y2);
	};

	bool is_vert() {
		return x1 == x2;
	}
};

struct comp_cross_x : public binary_function<Cross,Cross,bool> {
	bool operator() (const Cross &a, const Cross &b) {
		if (a.x == b.x) return a.y < b.y;
		else return a.x < b.x;
	};
};

struct comp_cross_y : public binary_function<Cross,Cross,bool> {
	bool operator() (const Cross &a, const Cross &b) {
		if (a.y == b.y) return a.x < b.x;
		else return a.y < b.y;
	};
};

struct comp_cut_x : public binary_function<Cut, Cut, bool> {
	bool operator() (const Cut &a, const Cut &b) {
		if (a.x1 == b.x1) return a.y1 < b.y1;
		else return a.x1 < b.x1;
	};
};

struct comp_cut_y : public binary_function<Cut, Cut, bool> {
	bool operator() (const Cut &a, const Cut &b) {
		if (a.y1 == b.y1) return a.x1 < b.x1;
		else return a.y1 < b.y1;
	};
};

struct heap_comp_cut : public binary_function<Cut*, Cut*, bool> {
	bool operator() (const Cut *a, const Cut *b) {
		if (a->x1 == b->x1) return a->y1 > b->y1;
		else return a->x1 > b->x1;
	};
};


vector<Cross> vcross_list;
vector<Cross> hcross_list;
vector<Cut> vcut_list;
vector<Cut> hcut_list;
vector<Tree> vtree_list;
vector<Tree> htree_list;
vector<bool> vused;
vector<bool> hused;

priority_queue<Cut*, vector<Cut*>, heap_comp_cut> free_cuts;

int min_x, max_x, min_y, max_y;
int n;

void init() {
	int x1, y1, x2, y2;

	min_x = min_y = (int) 1e9;
	max_x = max_y = (int) -1e9;

	//cin >> n;
	scanf("%d", &n);
	if (n == 0) exit(0);

	vused.clear();
	hused.clear();
	vused.resize(2*n);
	hused.resize(2*n);

	vcut_list.clear();
	hcut_list.clear();
	vcross_list.clear();
	hcross_list.clear();

	for (int i = 0; i < n; i++) {
	//	cin >> x1 >> y1 >> x2 >> y2;
		scanf("%d%d%d%d", &x1, &y1, &x2, &y2);
		if (x1 < min_x) min_x = x1;
		if (y1 < min_y) min_y = y1;
		if (x2 > max_x) max_x = x2;
		if (y2 > max_y) max_y = y2;

		vcross_list.push_back(Cross(x1, y1));
		vcross_list.push_back(Cross(x1, y2));
		vcross_list.push_back(Cross(x2, y1));
		vcross_list.push_back(Cross(x2, y2));

		vcut_list.push_back(Cut(x1, y1, x1, y2));
		vcut_list.push_back(Cut(x2, y1, x2, y2));

		hcut_list.push_back(Cut(x1, y1, x2, y1));
		hcut_list.push_back(Cut(x1, y2, x2, y2));
	}
	sort(vcross_list.begin(), vcross_list.end(), comp_cross_x());
	vcross_list.erase(unique(vcross_list.begin(), vcross_list.end()), vcross_list.end());
	hcross_list = vcross_list;
	sort(hcross_list.begin(), hcross_list.end(), comp_cross_y());


	vtree_list.clear();
	htree_list.clear();

	// calculate tree info
	vcross_list[0].ti = vcross_list[0].tp = 0;
	for (int i = 0, j = 1, k = 0; j < vcross_list.size(); ++j) {
		if (vcross_list[j].x == vcross_list[j-1].x) {
			vcross_list[j].ti = i;
			vcross_list[j].tp = ++k;
		} else {
			vtree_list.push_back(Tree(vcross_list[j-1].tp));
			vcross_list[j].ti = ++i;
			vcross_list[j].tp = k = 0;
		}
	}
	vtree_list.push_back(Tree(vcross_list.back().tp));

	hcross_list[0].ti = hcross_list[0].tp = 0;
	for (int i = 0, j = 1, k = 0; j < hcross_list.size(); ++j) {
		if (hcross_list[j].y == hcross_list[j-1].y) {
			hcross_list[j].ti = i;
			hcross_list[j].tp = ++k;
		} else {
			htree_list.push_back(Tree(hcross_list[j-1].tp));
			hcross_list[j].ti = ++i;
			hcross_list[j].tp = k = 0;
		}
	}
	htree_list.push_back(Tree(hcross_list.back().tp));


	// concatenate cuts
	sort(vcut_list.begin(), vcut_list.end(), comp_cut_x());
	sort(hcut_list.begin(), hcut_list.end(), comp_cut_y());
	int i = 0;
	for (int j = 1; j < vcut_list.size(); ++j) {
		if ((vcut_list[j].x1 == vcut_list[i].x1) && (vcut_list[j].y1 <= vcut_list[i].y2))
			vcut_list[i].y2 = max(vcut_list[j].y2, vcut_list[i].y2);
		else
			vcut_list[++i] = vcut_list[j];
	}
	vcut_list.resize(i);

	i = 0;
	for (int j = 1; j < hcut_list.size(); ++j) {
		if ((hcut_list[j].y1 == hcut_list[i].y1) && (hcut_list[j].x1 <= hcut_list[i].x2))
			hcut_list[i].x2 = max(hcut_list[j].x2, hcut_list[i].x2);
		else
			hcut_list[++i] = hcut_list[j];
	}
	hcut_list.resize(i);
}

void solve() {
	// add cuts to appropriate trees
	for (int i = 1; i < vcut_list.size(); i++) {
		vector<Cross>::iterator j = lower_bound(vcross_list.begin(), vcross_list.end(),
						Cross(vcut_list[i].x1, vcut_list[i].y1), comp_cross_x());
		vtree_list[j->ti].add(j->tp, i);
	}

	for (int i = 1; i < hcut_list.size(); i++) {
		vector<Cross>::iterator j = lower_bound(hcross_list.begin(), hcross_list.end(),
						Cross(hcut_list[i].x1, hcut_list[i].y1), comp_cross_y());
		htree_list[j->ti].add(j->tp, i);
	}


	// mark end crosses as free
	for (int i = 0; i < vcross_list.size(); i++) {
		if (vcross_list[i].x == min_x || vcross_list[i].x == max_x) continue;
		if (vcross_list[i].y == min_y || vcross_list[i].y == max_y) {
			int j = vtree_list[vcross_list[i].ti].query(vcross_list[i].tp);

			assert(j >= 0);
			assert(vcut_list[j].x1 == vcross_list[i].x);
			assert(vcut_list[j].y1 <= vcross_list[i].y);
			assert(vcut_list[j].y2 >= vcross_list[i].y);

			if (vcut_list[j].y1 == vcross_list[i].y) {
				vcut_list[j].u1 = true;
				if (vcut_list[j].u2) {
					vused[j] = true;
					free_cuts.push(&vcut_list[j]);
				}
			} else if (vcut_list[j].y2 == vcross_list[i].y) {
				vcut_list[j].u2 = true;
				if (vcut_list[j].u1) {
					vused[j] = true;
					free_cuts.push(&vcut_list[j]);
				}
			}
		}
	}

	for (int i = 0; i < hcross_list.size(); i++) {
		if (hcross_list[i].y == min_y || hcross_list[i].y == max_y) continue;
		if (hcross_list[i].x == min_x || hcross_list[i].x == max_x) {
			int j = htree_list[hcross_list[i].ti].query(hcross_list[i].tp);

			assert(j >= 0);
			assert(hcut_list[j].y1 == hcross_list[i].y);
			assert(hcut_list[j].x1 <= hcross_list[i].x);
			assert(hcut_list[j].x2 >= hcross_list[i].x);

			if (hcut_list[j].x1 == hcross_list[i].x) {
				hcut_list[j].u1 = true;
				if (hcut_list[j].u2) free_cuts.push(&hcut_list[j]);
			} else if (hcut_list[j].x2 == hcross_list[i].x) {
				hcut_list[j].u2 = true;
				if (hcut_list[j].u1) free_cuts.push(&hcut_list[j]);
			}
		}
	}


	//cout << n-1 << endl;
	printf("%d\n", n-1);
	while (!free_cuts.empty()) {
		Cut* c = free_cuts.top();
		free_cuts.pop();

		c->placed = true;
		c->print();

		if (c->is_vert()) {
			vector<Cross>::iterator start = lower_bound(vcross_list.begin(), vcross_list.end(),
								Cross(c->x1, c->y1),comp_cross_x());
			vector<Cross>::iterator bound = lower_bound(vcross_list.begin(),vcross_list.end(),
								Cross(c->x2, c->y2),comp_cross_x());
			vector<Cross>::iterator j = start;
			for (++j; j != bound; ++j) {

				assert(j->x == c->x1);
				assert(j->y >= c->y1);
				assert(j->y <= c->y2);

				assert(j->y != min_y);
				assert(j->y != max_y);

//				if (j->y == min_y || j->y == max_y) continue;

				vector<Cross>::iterator k = lower_bound(hcross_list.begin(), hcross_list.end(),
									*j, comp_cross_y());
				int s = htree_list[k->ti].query(k->tp);
				assert(s >= 0);
				assert(hcut_list[s].y1 == k->y);
				assert(hcut_list[s].x1 <= k->x);
				assert(hcut_list[s].x2 >= k->x);
				//if (hcut_list[s].placed) continue;
				assert(!hcut_list[s].placed);

				if (hcut_list[s].x1 == k->x) {
					hcut_list[s].u1 = true;
					if (hcut_list[s].u2 && !hused[s]) {
						hused[s] = true;
						free_cuts.push(&hcut_list[s]);
					}
				} else if (hcut_list[s].x2 == k->x) {
					hcut_list[s].u2 = true;
					if (hcut_list[s].u1 && !hused[s]) {
						hused[s] = true;
						free_cuts.push(&hcut_list[s]);
					}
				} else {
					hcut_list.push_back(Cut(k->x, k->y, hcut_list[s].x2, k->y, true, hcut_list[s].u2));
					htree_list[k->ti].add(k->tp, hcut_list.size() - 1);
					if (hcut_list[s].u2) {
						hused[hcut_list.size() - 1] = true;
						free_cuts.push(&hcut_list[hcut_list.size() - 1]);
					}

					hcut_list[s].x2 = k->x;
					hcut_list[s].u2 = true;
					if (hcut_list[s].u1 && !hused[s]) {
						hused[s] = true;
						free_cuts.push(&hcut_list[s]);
					}
				}
			}
		} else {
			vector<Cross>::iterator start = lower_bound(hcross_list.begin(), hcross_list.end(),
								Cross(c->x1, c->y1),comp_cross_y());
			vector<Cross>::iterator bound = lower_bound(hcross_list.begin(), hcross_list.end(),
								Cross(c->x2, c->y2),comp_cross_y());

			vector<Cross>::iterator j = start;
			for (++j; j != bound; ++j) {

				assert(j->y == c->y1);
				assert(j->x >= c->x1);
				assert(j->x <= c->x2);
				assert(j->x != min_x);
				assert(j->x != max_x);
				//if (j->x == min_x || j->x == max_x) continue;

				vector<Cross>::iterator k = lower_bound(vcross_list.begin(), vcross_list.end(),
									*j, comp_cross_x());
				int s = vtree_list[k->ti].query(k->tp);
				assert(s >= 0);
				assert(vcut_list[s].x1 == k->x);
				assert(vcut_list[s].y1 <= k->y);
				assert(vcut_list[s].y2 >= k->y);
				//if (vcut_list[s].placed) continue;
				assert(!vcut_list[s].placed);

				if (vcut_list[s].y1 == k->y) {
					vcut_list[s].u1 = true;
					if (vcut_list[s].u2 && !vused[s]) {
						vused[s] = true;
						free_cuts.push(&vcut_list[s]);
					}
				} else if (vcut_list[s].y2 == k->y) {
					vcut_list[s].u2 = true;
					if (vcut_list[s].u1 && !vused[s]) {
						vused[s] = true;
						free_cuts.push(&vcut_list[s]);
					}
				} else {
					vcut_list.push_back(Cut(k->x, k->y, k->x, vcut_list[s].y2, true, vcut_list[s].u2));
					vtree_list[k->ti].add(k->tp, vcut_list.size() - 1);
					if (vcut_list[s].u2) {
						vused[vcut_list.size() - 1] = true;
						free_cuts.push(&vcut_list[vcut_list.size() - 1]);
					}

					vcut_list[s].y2 = k->y;
					vcut_list[s].u2 = true;
					if (vcut_list[s].u1 && !vused[s]) {
						vused[s] = true;
						free_cuts.push(&vcut_list[s]);
					}
				}
			}
		}
	}
}

int main() {
	init();
	solve();
	return 0;
}
