#include <iostream>
#include <vector>
#include <functional>
#include <algorithm>
#include <queue>

#include <assert.h>
#include <stdlib.h>

using namespace std;

struct Cross {
	int x, y;
	int ti, tp;

	Cross(int a, int b) : x(a), y(b) {};
	bool operator==(const Cross &a) {
		return (a.x == x) && (a.y == y);
	}
	void print() {
		cout << x << " " << y << "; tree " << ti << " " << tp << endl;
	}
};


struct Cut {
	int x1, y1;
	int x2, y2;
	int num;
	int pn;

	Cut() : x1(0), y1(0), x2(0), y2(0), num(0) {};
	Cut(int a, int b, int c, int d) : x1(a), y1(b), x2(c), y2(d), num(0)
		{assert(x1<=x2); assert(y1<=y2);};

	void print() {
		//cout << x1 << " " << y1 << " " << x2 << " " << y2 << endl;
		printf("%d %d %d %d\n", x1, y1, x2, y2);
	};

	bool is_vert() {
		return x1 == x2;
	}
};

struct comp_cross_x : public binary_function<Cross,Cross,bool> {
	bool operator() (const Cross &a, const Cross &b) {
		if (a.x == b.x) return a.y < b.y;
		else return a.x < b.x;
	};
};

struct comp_cross_y : public binary_function<Cross,Cross,bool> {
	bool operator() (const Cross &a, const Cross &b) {
		if (a.y == b.y) return a.x < b.x;
		else return a.y < b.y;
	};
};

struct comp_cut_x : public binary_function<Cut, Cut, bool> {
	bool operator() (const Cut &a, const Cut &b) {
		if (a.x1 == b.x1) return a.y1 < b.y1;
		else return a.x1 < b.x1;
	};
};

struct comp_cut_y : public binary_function<Cut, Cut, bool> {
	bool operator() (const Cut &a, const Cut &b) {
		if (a.y1 == b.y1) return a.x1 < b.x1;
		else return a.y1 < b.y1;
	};
};

struct comp_cut_pn : public binary_function<Cut, Cut, bool> {
	bool operator() (const Cut &a, const Cut &b) {
		return a.pn < b.pn;
	}
};

struct heap_comp_cut : public binary_function<Cut*, Cut*, bool> {
	bool operator() (const Cut *a, const Cut *b) {
		if (a->x1 == b->x1) return a->y1 > b->y1;
		else return a->x1 > b->x1;
	};
};

vector<Cut> hcut_list;
vector<Cut> vcut_list;

vector<Cut> result;
priority_queue<Cut*, vector<Cut*>, heap_comp_cut> free_cuts;

int cnum;
int min_x, max_x, min_y, max_y;
int n;

void init() {
	int x1, y1, x2, y2;

	min_x = min_y = (int) 1e9;
	max_x = max_y = (int) -1e9;

	//cin >> n;
	scanf("%d", &n);
	if (n == 0) exit(0);

	vcut_list.clear();
	hcut_list.clear();
	//cross_list.clear();

	for (int i = 0; i < n; i++) {
		//cin >> x1 >> y1 >> x2 >> y2;
		scanf("%d%d%d%d", &x1, &y1, &x2, &y2);

		if (x1 < min_x) min_x = x1;
		if (y1 < min_y) min_y = y1;
		if (x2 > max_x) max_x = x2;
		if (y2 > max_y) max_y = y2;

		/*
		cross_list.push_back(Cross(x1, y1));
		cross_list.push_back(Cross(x1, y2));
		cross_list.push_back(Cross(x2, y1));
		cross_list.push_back(Cross(x2, y2));
		*/

		vcut_list.push_back(Cut(x1, y1, x1, y2));
		vcut_list.push_back(Cut(x2, y1, x2, y2));
		hcut_list.push_back(Cut(x1, y1, x2, y1));
		hcut_list.push_back(Cut(x1, y2, x2, y2));
	}

	// concatenate cuts
	sort(vcut_list.begin(), vcut_list.end(), comp_cut_x());
	sort(hcut_list.begin(), hcut_list.end(), comp_cut_y());
	int i = 0;
	for (int j = 1; j < vcut_list.size(); ++j) {
		if ((vcut_list[j].x1 == vcut_list[i].x1) && (vcut_list[j].y1 <= vcut_list[i].y2))
			vcut_list[i].y2 = max(vcut_list[j].y2, vcut_list[i].y2);
		else
			vcut_list[++i] = vcut_list[j];
	}
	vcut_list.resize(i);

	i = 0;
	for (int j = 1; j < hcut_list.size(); ++j) {
		if ((hcut_list[j].y1 == hcut_list[i].y1) && (hcut_list[j].x1 <= hcut_list[i].x2))
			hcut_list[i].x2 = max(hcut_list[j].x2, hcut_list[i].x2);
		else
			hcut_list[++i] = hcut_list[j];
	}
	hcut_list.resize(i);
}

void solve(vector<Cut> &cuts, int a, int b, int c, int d) {
	int pn;
	vector<Cut> lcuts;
	vector<Cut> rcuts;
	Cut cr;

	pn = cnum;

while (cuts.size() > 1) {
	//cout << "Solve...." << endl;
	//for (vector<Cut>::iterator i = cuts.begin(); i != cuts.end(); ++i)
	//	i->print();
	//cout << endl;

	cr.x1 = max_x; cr.y1 = max_y;
	lcuts.clear();
	rcuts.clear();

	for (vector<Cut>::iterator i = cuts.begin(); i != cuts.end(); ++i) {
		if (i->is_vert()) {
			if (i->y1 > b || i->y2 < d) continue;
			if (comp_cut_x()(*i, cr))
				cr = *i;
		} else {
			if (i->x1 > a || i->x2 < c) continue;
			if (comp_cut_x()(*i, cr))
				cr = *i;
		}
	}
	if (cr.is_vert()) {
		for (vector<Cut>::iterator i = cuts.begin(); i != cuts.end(); ++i) {
			if (i->is_vert()) {
				if (i->x1 < cr.x1) lcuts.push_back(*i);
				else if (i->x1 > cr.x2) rcuts.push_back(*i);
			} else {
				if (i->x1 < cr.x1) {
					if (i->x2 > cr.x2) {
						lcuts.push_back(Cut(i->x1, i->y1, cr.x2, i->y2));
						rcuts.push_back(Cut(cr.x2, i->y1, i->x2, i->y2));
					} else
						lcuts.push_back(*i);
				} else {
					rcuts.push_back(*i);
				}
			}
		}
	} else {
		for (vector<Cut>::iterator i = cuts.begin(); i != cuts.end(); ++i) {
			if (i->is_vert()) {
				if (i->y1 < cr.y1) {
					if (i->y2 > cr.y2) {
						lcuts.push_back(Cut(i->x1, i->y1, i->x2, cr.y1));
						rcuts.push_back(Cut(i->x1, cr.y1, i->x2, i->y2));
					} else
						lcuts.push_back(*i);
				} else
					rcuts.push_back(*i);
			} else {
				if (i->y1 < cr.y1) lcuts.push_back(*i);
				else if (i->y1 > cr.y2) rcuts.push_back(*i);
			}
		}
	}

	cr.pn = pn;
	cr.num = ++cnum;
	result.push_back(cr);
	pn = cnum;

	cuts.clear();

	if (cr.is_vert()) {
		if (lcuts.size() < rcuts.size()) {
			solve(lcuts, a, b, cr.x1, d);
	//	solve(rcuts, cr.x2, b, c, d);
			cuts = rcuts;
			a = cr.x2;
		} else {
			solve(rcuts, cr.x1, b, c, d);
			cuts = lcuts;
			c = cr.x1;
		}
	} else {
		if (lcuts.size() < rcuts.size()) {
			solve(lcuts, a, b, c, cr.y1);
	//	solve(rcuts, a, cr.y1, c, d);
			cuts = rcuts;
			b = cr.y1;
		} else {
			solve(rcuts, a, cr.y1, c, d);
			cuts = lcuts;
			d = cr.y1;
		}
	}
}
	if (cuts.size() == 1) {
		cr = *cuts.begin();

		cr.pn = pn;
		cr.num = ++cnum;
		result.push_back(cr);
		pn = cnum;
		return;
	}
}

int main() {
	vector<Cut> cut_list;

//	while (1) {
		result.clear();

		init();

		/*
		for (vector<Cut>::iterator i = vcut_list.begin(); i != vcut_list.end(); ++i)
			i->print();
		for (vector<Cut>::iterator i = hcut_list.begin(); i != hcut_list.end(); ++i)
			i->print();
		return 1;
		*/

		cut_list.clear();
		cut_list.insert(cut_list.end(), vcut_list.begin()+1, vcut_list.end());
		cut_list.insert(cut_list.end(), hcut_list.begin()+1, hcut_list.end());

		cnum = 0;
		solve(cut_list, min_x, min_y, max_x, max_y);

		printf("%d\n", n-1);
		sort(result.begin(), result.end(), comp_cut_pn());
		free_cuts.push(&result[0]);
		while (!free_cuts.empty()) {
			Cut *c = free_cuts.top();
			free_cuts.pop();
			c->print();

			Cut t;
			t.pn = c->num;
			vector<Cut>::iterator n = lower_bound(result.begin(), result.end(), t, comp_cut_pn());
			while (n->pn == c->num) {
				free_cuts.push(&(*n));
				++n;
			}
		}

//		cout << endl;
//	}

	return 0;
}
